@@ -4,7 +4,7 @@ import shutil
 import glob
 from copy import deepcopy
 from typing import Optional, List
-
+import tempfile
 from rotab.loader.loader import Loader
 from rotab.loader.schema_manager import SchemaManager
 from rotab.loader.context_builder import ContextBuilder
@@ -98,6 +98,7 @@ class Pipeline:
         for template in self.templates:
             for proc in template.processes:
                 for node in proc.inputs:
+
                     if self.is_remote_path(node.path):
                         continue
 
@@ -189,18 +190,76 @@ class Pipeline:
         logger.info(f"Mermaid DAG generated at: {path}")
 
     def execute_script(self, source_dir: str) -> None:
+        # 1) /opt/ml/tmp の中身だけ削除（ディレクトリ自体は残す）
+        opt_tmp = "/opt/ml/tmp"
+        if os.path.isdir(opt_tmp):
+            try:
+                for name in os.listdir(opt_tmp):
+                    path = os.path.join(opt_tmp, name)
+                    try:
+                        if os.path.isdir(path) and not os.path.islink(path):
+                            shutil.rmtree(path, ignore_errors=True)
+                        else:
+                            os.remove(path)
+                    except FileNotFoundError:
+                        pass
+                    except IsADirectoryError:
+                        shutil.rmtree(path, ignore_errors=True)
+                    except Exception as ex:
+                        logger.warning(f"cleanup skip: {path} ({ex})")
+            except Exception as ex:
+                logger.warning(f"failed to clean {opt_tmp}: {ex}")
+        else:
+            try:
+                os.makedirs(opt_tmp, exist_ok=True)
+            except Exception as ex:
+                logger.warning(f"failed to create {opt_tmp}: {ex}")
+
+        # 2) 実行用の一時ディレクトリ作成（/opt/ml/tmp 優先）
+        tmpdir_base = opt_tmp if os.path.isdir(opt_tmp) else "/tmp"
         try:
-            subprocess.run(
-                ["python", "main.py"],
+            tmpdir = tempfile.mkdtemp(prefix="rotab_tmp_", dir=tmpdir_base)
+        except FileNotFoundError:
+            os.makedirs("/tmp", exist_ok=True)
+            tmpdir = tempfile.mkdtemp(prefix="rotab_tmp_", dir="/tmp")
+
+        # 3) 子プロセス環境設定
+        env = os.environ.copy()
+        env.update(
+            {
+                "TMPDIR": tmpdir,
+                "TEMP": tmpdir,
+                "TMP": tmpdir,
+                "ARROW_TMPDIR": tmpdir,
+                "POLARS_TEMP_DIR": tmpdir,
+                "XDG_CACHE_HOME": tmpdir,
+                "JUPYTER_RUNTIME_DIR": tmpdir,
+                "PYTHONUNBUFFERED": "1",
+            }
+        )
+
+        try:
+            proc = subprocess.Popen(
+                ["python", "-u", "main.py"],
                 cwd=source_dir,
-                check=True,
-                capture_output=True,
+                env=env,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
                 text=True,
+                bufsize=1,
             )
-        except subprocess.CalledProcessError as e:
+
+            for line in iter(proc.stdout.readline, ""):
+                if not line:
+                    break
+                logger.info(line.rstrip())
+
+            proc.wait()
+            if proc.returncode != 0:
+                raise subprocess.CalledProcessError(proc.returncode, proc.args)
+
+        except subprocess.CalledProcessError:
             logger.error("Script execution failed.")
-            logger.error(f"STDOUT:\n{e.stdout}")
-            logger.error(f"STDERR:\n{e.stderr}")
             raise
 
     def run(self, execute: bool = True, dag: bool = False, selected_processes: Optional[List[str]] = None) -> None:
